# Introduction

## Overview

The Earnix Elevate SDK provides a programmatic alternative to the web interface for creating and managing Elevate entities and processes. It provides a complete set of Python tools to work and interact with its components. These tools can be leveraged anywhere you can write code (for example, IDEs, notebooks, etc.).

## Requirements

- Python >= 3.9.
- An Earnix Elevate account.
- Valid `client_id` and `secret_key`, linked to that account or to a user within that account.

## Disclaimer

This package uses open-source software. The licenses of its dependencies can be viewed [here](https://content.e2.earnix.com/sdk/THIRD_PARTY_LICENSES.txt).
